local mod = HideBlizzard:NewModule('Player', 'AceEvent-3.0')
mod.modName = 'Player'

local options = {
	armoredman = {
		type = 'toggle',
		name = 'Armored Man',
		desc = 'Hide the standard armored man frame.',
		get = function() return mod.db.profile.armoredman end,
		set = function(info, v)
			mod.db.profile.armoredman = v
			if v then
				mod:EnableArmoredMan()
			else
				mod:DisableArmoredMan()
			end
		end,
		disabled = function() return not HideBlizzard.db.profile.modules.Player end,
	},
	aura = {
		type = 'toggle',
		name = 'Aura',
		desc = 'Hide the standard buff / debuff frame.',
		get = function() return mod.db.profile.aura end,
		set = function(info, v)
			mod.db.profile.aura = v
			if v then
				mod:EnableAura()
			else
				mod:DisableAura()
			end
		end,
		disabled = function() return not HideBlizzard.db.profile.modules.Player end,
	},
	playercastbar = {
		type = 'toggle',
		name = 'Player Cast Bar',
		desc = 'Hide the standard player cast bar frame.',
		get = function() return mod.db.profile.playercastbar end,
		set = function(info, v)
			mod.db.profile.playercastbar = v
			if v then
				mod:EnablePlayerCastBar()
			else
				mod:DisablePlayerCastBar()
			end
		end,
		disabled = function() return not HideBlizzard.db.profile.modules.Player end,
	},
	playerunitframe = {
		type = 'toggle',
		name = 'Player Unit Frame',
		desc = 'Hide the standard player unit frame.',
		get = function() return mod.db.profile.playerunitframe end,
		set = function(info, v)
			mod.db.profile.playerunitframe = v
			if v then
				mod:EnablePlayerUnitFrame()
			else
				mod:DisablePlayerUnitFrame()
			end
		end,
		disabled = function() return not HideBlizzard.db.profile.modules.Player end,
	},
	runeframe = {
		type = 'toggle',
		name = 'Rune Frame',
		desc = 'Hide the standard rune frame.',
		get = function() return mod.db.profile.runeframe end,
		set = function(info, v)
			mod.db.profile.runeframe = v
			if v then
				mod:EnableRuneFrame()
			else
				mod:DisableRuneFrame()
			end
		end,
		disabled = function() return not HideBlizzard.db.profile.modules.Player or select(2, UnitClass('player')) ~= 'DEATHKNIGHT' end,
	},
}

local defaults = {
	profile = {
		armoredman = false,
		aura = false,
		playercastbar = false,
		playerunitframe = false,
		runeframe = false,
	}
}

function mod:OnInitialize()
	self.db = HideBlizzard.db:RegisterNamespace('Player', defaults)
end

function mod:OnEnable()
	self:UpdateFrames()
end

function mod:OnDisable()
	self:DisableArmoredMan()
	self:DisableAura()
	self:DisablePlayerCastBar()
	self:DisablePlayerUnitFrame()
	self:DisableRuneFrame()
end

function mod:UpdateFrames()
	if mod.db.profile.armoredman == true then
		self:EnableArmoredMan()
	else
		self:DisableArmoredMan()
	end
	if mod.db.profile.aura == true then
		self:EnableAura()
	else
		self:DisableAura()
	end
	if mod.db.profile.playercastbar == true then
		self:EnablePlayerCastBar()
	else
		self:DisablePlayerCastBar()
	end
	if mod.db.profile.playerunitframe == true then
		self:EnablePlayerUnitFrame()
	else
		self:DisablePlayerUnitFrame()
	end
	if mod.db.profile.runeframe == true then
		self:EnableRuneFrame()
	else
		self:DisableRuneFrame()
	end
end

function mod:EnableArmoredMan()
	DurabilityFrame:UnregisterAllEvents()
	DurabilityFrame:Hide() 
end

function mod:DisableArmoredMan()
	DurabilityFrame:RegisterEvent('UNIT_INVENTORY_CHANGED')
	DurabilityFrame:RegisterEvent('UPDATE_INVENTORY_ALERTS')
end

function mod:EnableAura()
	BuffFrame:UnregisterAllEvents()
	BuffFrame:Hide()
	TemporaryEnchantFrame:Hide()
end

function mod:DisableAura()
	TemporaryEnchantFrame:Show()
	BuffFrame:Show()
	BuffFrame:RegisterEvent('UNIT_AURA')
	BuffFrame:RegisterEvent('PLAYER_AURAS_CHANGED')
	BuffFrame_Update(BuffFrame)
end

function mod:EnablePlayerCastBar()
	CastingBarFrame:UnregisterAllEvents()
	CastingBarFrame:Hide()
end

function mod:DisablePlayerCastBar()
	CastingBarFrame:RegisterEvent('UNIT_SPELLCAST_START')
	CastingBarFrame:RegisterEvent('UNIT_SPELLCAST_STOP')
	CastingBarFrame:RegisterEvent('UNIT_SPELLCAST_FAILED')
	CastingBarFrame:RegisterEvent('UNIT_SPELLCAST_INTERRUPTED')
	CastingBarFrame:RegisterEvent('UNIT_SPELLCAST_DELAYED')
	CastingBarFrame:RegisterEvent('UNIT_SPELLCAST_CHANNEL_START')
	CastingBarFrame:RegisterEvent('UNIT_SPELLCAST_CHANNEL_UPDATE')
	CastingBarFrame:RegisterEvent('PLAYER_ENTERING_WORLD')
end

function mod:EnablePlayerUnitFrame()
	PlayerFrame:UnregisterAllEvents()
	PlayerFrameHealthBar:UnregisterAllEvents()
	PlayerFrameManaBar:UnregisterAllEvents()
	PlayerFrame:Hide()
end

function mod:DisablePlayerUnitFrame()
	PlayerFrame:RegisterEvent('UNIT_LEVEL')
	PlayerFrame:RegisterEvent('UNIT_COMBAT')
	PlayerFrame:RegisterEvent('UNIT_SPELLMISS')
	PlayerFrame:RegisterEvent('UNIT_PVP_UPDATE')
	PlayerFrame:RegisterEvent('UNIT_MAXMANA')
	PlayerFrame:RegisterEvent('PLAYER_ENTER_COMBAT')
	PlayerFrame:RegisterEvent('PLAYER_LEAVE_COMBAT')
	PlayerFrame:RegisterEvent('PLAYER_UPDATE_RESTING')
	PlayerFrame:RegisterEvent('PARTY_MEMBERS_CHANGED')
	PlayerFrame:RegisterEvent('PARTY_LEADER_CHANGED')
	PlayerFrame:RegisterEvent('PARTY_LOOT_METHOD_CHANGED')
	PlayerFrame:RegisterEvent('PLAYER_ENTERING_WORLD')
	PlayerFrame:RegisterEvent('PLAYER_REGEN_DISABLED')
	PlayerFrame:RegisterEvent('PLAYER_REGEN_ENABLED')
	PlayerFrameHealthBar:RegisterEvent('UNIT_HEALTH')
	PlayerFrameHealthBar:RegisterEvent('UNIT_MAXHEALTH')
	PlayerFrameManaBar:RegisterEvent('UNIT_MANA')
	PlayerFrameManaBar:RegisterEvent('UNIT_RAGE')
	PlayerFrameManaBar:RegisterEvent('UNIT_FOCUS')
	PlayerFrameManaBar:RegisterEvent('UNIT_ENERGY')
	PlayerFrameManaBar:RegisterEvent('UNIT_RUNIC_POWER')
	PlayerFrameManaBar:RegisterEvent('UNIT_HAPPINESS')
	PlayerFrameManaBar:RegisterEvent('UNIT_MAXMANA')
	PlayerFrameManaBar:RegisterEvent('UNIT_MAXRAGE')
	PlayerFrameManaBar:RegisterEvent('UNIT_MAXFOCUS')
	PlayerFrameManaBar:RegisterEvent('UNIT_MAXENERGY')
	PlayerFrameManaBar:RegisterEvent('UNIT_MAXRUNIC_POWER')
	PlayerFrameManaBar:RegisterEvent('UNIT_MAXHAPPINESS')
	PlayerFrameManaBar:RegisterEvent('UNIT_RUNIC_POWER')
	PlayerFrameManaBar:RegisterEvent('UNIT_DISPLAYPOWER')
	PlayerFrame:RegisterEvent('UNIT_NAME_UPDATE')
	PlayerFrame:RegisterEvent('UNIT_PORTRAIT_UPDATE')
	PlayerFrame:RegisterEvent('UNIT_DISPLAYPOWER')
	PlayerFrame:Show()
	PlayerFrame_Update(PlayerFrame)
end

function mod:EnableRuneFrame()
	local _, class = UnitClass('player')
	if (class == 'DEATHKNIGHT') then
		RuneFrame:UnregisterAllEvents()
		RuneFrame:Hide()
	end
end

function mod:DisableRuneFrame()
	local _, class = UnitClass('player')
	if (class == 'DEATHKNIGHT') then
		RuneFrame:Show()
		RuneFrame:RegisterEvent('RUNE_POWER_UPDATE')
		RuneFrame:RegisterEvent('RUNE_TYPE_UPDATE')
		RuneFrame:RegisterEvent('UNIT_RUNIC_POWER')
		RuneFrame:RegisterEvent('UNIT_MAXRUNIC_POWER')
		RuneFrame:RegisterEvent('PLAYER_ENTERING_WORLD')
	else
		return
	end
end

function mod:Info()
	return 'Hides various player related frames.'
end

function mod:GetOptions()
	return options
end