local mod = HideBlizzard:NewModule('SpecialFrames')
mod.modName = 'Special Frames'

local options = {
	tooltip = {
		type = 'toggle',
		name = 'Tooltip',
		desc = 'Hide the standard tooltip frame.',
		get = function() return mod.db.profile.tooltip end,
		set = function(info, v)
			mod.db.profile.tooltip = v
			if v then
				mod:EnableTooltip()
			else
				mod:DisableTooltip()
			end
		end,
		disabled = function() return not HideBlizzard.db.profile.modules.SpecialFrames end,
	},
}

local defaults = {
	profile = {
		tooltip = false,
	}
}

function mod:OnInitialize()
	self.db = HideBlizzard.db:RegisterNamespace('Special Frames', defaults)
end

function mod:OnEnable()
	self:UpdateFrames()
end

function mod:OnDisable()
	self:DisableTooltip()
end

function mod:UpdateFrames()
	if mod.db.profile.tooltip == true then
		self:EnableTooltip()
	else
		self:DisableTooltip()
	end
end

function mod:EnableTooltip()
	hooksecurefunc('GameTooltip_SetDefaultAnchor', function(tooltip, parent)
		if IsAddOnLoaded('TipTac') then
			return
		else
			tooltip:SetOwner(parent, 'ANCHOR_NONE')
			tooltip:Hide()
		end
	end)
end

function mod:DisableTooltip()
	hooksecurefunc('GameTooltip_SetDefaultAnchor', function(tooltip, parent)
		if IsAddOnLoaded('TipTac') then
			return
		else
			tooltip:SetOwner(parent, 'ANCHOR_NONE')
			tooltip:SetPoint('BOTTOMRIGHT', 'UIParent', 'BOTTOMRIGHT', -CONTAINER_OFFSET_X - 13, CONTAINER_OFFSET_Y)
		end
	end)
end

function mod:Info()
	return 'Hides various special ui frames.'
end

function mod:GetOptions()
	return options
end